@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.016_001'; # TRIAL VERSION
+our $VERSION = '0.016_002'; # TRIAL VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -62,6 +62,16 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my ($self) = @_;
+    my $clone = {
+        schema => $self->schema,
+        loader => $self->loader->clone,
+        dumper => $self->dumper->clone,
+    };
+    return bless $clone, ref $self;
+}
+
 sub loader {
     if (@_ > 1) {
         $_[0]->{loader} = $_[1]
@@ -284,6 +294,10 @@ In progress. Keeping hash key order.
 
 YAML 1.1 merge keys for mappings
 
+=item L<YAML::PP::Schema::Include>
+
+Include other YAML files via C<!include> tags
+
 =back
 
 To make the parsing process faster, you can plugin the libyaml parser
@@ -435,12 +449,6 @@ dumped correctly by modules like L<JSON::PP> or L<JSON::XS>, for example.
 
 See L<"NUMBERS"> for an example.
 
-=back
-
-TODO:
-
-=over 4
-
 =item Complex Keys
 
 Mapping Keys in YAML can be more than just scalars. Of course, you can't load
@@ -472,6 +480,12 @@ Example:
        }
     }
 
+=back
+
+TODO:
+
+=over 4
+
 =item Parse Tree
 
 I would like to generate a complete parse tree, that allows you to manipulate
@@ -495,11 +509,20 @@ they will be dumped with double quotes.
 It will recognize JSON::PP::Boolean and boolean.pm objects and dump them
 correctly.
 
-TODO: Correctly recognize numbers which also have a string flag, like:
+Numbers which also have a PV flag will be recognized as numbers and not
+as strings:
 
     my $int = 23;
     say "int: $int"; # $int will now also have a PV flag
 
+That means that if you accidentally use a string in numeric context, it will
+also be recognized as a number:
+
+    my $string = "23";
+    my $something = $string + 0;
+    print $yp->dump_string($string);
+    # will be emitted as an integer without quotes!
+
 The layout is like libyaml output:
 
     key:
