@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Constructor;
 
-our $VERSION = '0.016_001'; # TRIAL VERSION
+our $VERSION = '0.016_002'; # TRIAL VERSION
 
 use YAML::PP;
 use Scalar::Util qw/ reftype /;
@@ -31,6 +31,15 @@ sub new {
     }, $class;
 }
 
+sub clone {
+    my ($self) = @_;
+    my $clone = {
+        schema => $self->schema,
+        cyclic_refs => $self->cyclic_refs,
+    };
+    return bless $clone, ref $self;
+}
+
 sub init {
     my ($self) = @_;
     $self->set_docs([]);
