@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Dumper;
 
-our $VERSION = '0.016_001'; # TRIAL VERSION
+our $VERSION = '0.016_002'; # TRIAL VERSION
 
 use Scalar::Util qw/ blessed refaddr reftype /;
 use YAML::PP;
@@ -51,6 +51,20 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my ($self) = @_;
+    my $clone = {
+        representer => $self->representer->clone,
+        emitter => $self->emitter->clone,
+        seen => {},
+        anchors => {},
+        anchor_num => 0,
+        header => $self->header,
+        footer => $self->footer,
+    };
+    return bless $clone, ref $self;
+}
+
 sub init {
     my ($self) = @_;
     $self->{seen} = {};
